@@ -14,7 +14,7 @@
 # ==============================================================================
 
 import numpy as np
-from model_compression_toolkit.core.common.logger import Logger
+from model_compression_toolkit.logger import Logger
 
 
 class BaseCollector(object):
