@@ -17,7 +17,7 @@ from typing import Callable, Any, List, Tuple, Dict
 
 import numpy as np
 
-from model_compression_toolkit import MixedPrecisionQuantizationConfigV2
+from model_compression_toolkit.core import MixedPrecisionQuantizationConfigV2
 from model_compression_toolkit.core import common
 from model_compression_toolkit.core.common import BaseNode
 from model_compression_toolkit.core.common.collectors.statistics_collector import BaseStatsCollector
@@ -94,7 +94,7 @@ class FrameworkImplementation(ABC):
                       mode: ModelBuilderMode,
                       append2output: List[Any],
                       fw_info: FrameworkInfo,
-                      return_float_outputs: bool = False) -> Tuple[Any, UserInformation]:
+                      return_float_outputs: bool = False) -> Tuple:
         """
         Build a framework model from a graph.
         The mode determines how the model should be build. append2output is a list of Nodes
@@ -108,7 +108,7 @@ class FrameworkImplementation(ABC):
             return_float_outputs (bool): whether to return outputs before or after quantization nodes (default)
 
         Returns:
-            A tuple of the model that was built and an UserInformation object.
+            A tuple with the model and additional relevant supporting objects.
         """
         raise NotImplemented(f'{self.__class__.__name__} have to implement the '
                              f'framework\'s model_builder method.')  # pragma: no cover
@@ -288,14 +288,6 @@ class FrameworkImplementation(ABC):
                              f'framework\'s get_substitutions_after_second_moment_correction '
                              f'method.')  # pragma: no cover
 
-    @abstractmethod
-    def get_gptq_trainer_obj(self):
-        """
-        Returns: GPTQTrainer object
-        """
-        raise NotImplemented(f'{self.__class__.__name__} have to implement the '
-                             f'framework\'s get_gptq_trainer method.')  # pragma: no cover
-
     @abstractmethod
     def get_sensitivity_evaluator(self,
                                   graph: Graph,
@@ -369,40 +361,6 @@ class FrameworkImplementation(ABC):
         raise NotImplemented(f'{self.__class__.__name__} have to implement the '
                              f'framework\'s get_node_distance_fn method.')  # pragma: no cover
 
-    @abstractmethod
-    def get_model_layers_names(self,
-                               model: Any) -> List[str]:
-        """
-        Returns a list of the given model's layers names.
-
-        Args:
-            model: A model.
-
-        Returns: List of layers' names.
-
-        """
-
-        raise NotImplemented(f'{self.__class__.__name__} have to implement the '
-                             f'framework\'s get_model_layers_names method.')  # pragma: no cover
-
-    @abstractmethod
-    def get_model_layer_by_name(self,
-                                model: Any,
-                                layer_name: str) -> Any:
-        """
-        Returns a model's layer by its name.
-
-        Args:
-            model: A model to retrieve a layer from.
-            layer_name: The requested layer's name.
-
-        Returns: A layer object.
-
-        """
-
-        raise NotImplemented(f'{self.__class__.__name__} have to implement the '
-                             f'framework\'s get_model_layer_by_name method.')  # pragma: no cover
-
     @abstractmethod
     def model_grad(self,
                    graph_float: common.Graph,
