@@ -18,8 +18,8 @@ from enum import Enum
 import numpy as np
 from typing import List, Callable, Dict
 
-from model_compression_toolkit import MixedPrecisionQuantizationConfigV2
-from model_compression_toolkit.core.common import Graph, Logger
+from model_compression_toolkit.core import MixedPrecisionQuantizationConfigV2
+from model_compression_toolkit.core.common import Graph
 from model_compression_toolkit.core.common.mixed_precision.kpi_tools.kpi import KPI, KPITarget
 from model_compression_toolkit.core.common.mixed_precision.kpi_tools.kpi_functions_mapping import kpi_functions_mapping
 from model_compression_toolkit.core.common.framework_implementation import FrameworkImplementation
@@ -30,6 +30,7 @@ from model_compression_toolkit.core.common.framework_info import FrameworkInfo
 from model_compression_toolkit.core.common.mixed_precision.solution_refinement_procedure import \
     greedy_solution_refinement_procedure
 from model_compression_toolkit.core.common.substitutions.apply_substitutions import substitute
+from model_compression_toolkit.logger import Logger
 
 
 class BitWidthSearchMethod(Enum):
