@@ -17,10 +17,12 @@ import copy
 import numpy as np
 from typing import Callable, Any, List
 
-from model_compression_toolkit import FrameworkInfo, MixedPrecisionQuantizationConfigV2
+from model_compression_toolkit.constants import AXIS
+from model_compression_toolkit.core import FrameworkInfo, MixedPrecisionQuantizationConfigV2
 from model_compression_toolkit.core.common import Graph, BaseNode
+from model_compression_toolkit.core.common.graph.functional_node import FunctionalNode
 from model_compression_toolkit.core.common.model_builder_mode import ModelBuilderMode
-from model_compression_toolkit.core.common import Logger
+from model_compression_toolkit.logger import Logger
 
 
 class SensitivityEvaluation:
@@ -36,7 +38,6 @@ class SensitivityEvaluation:
                  fw_info: FrameworkInfo,
                  fw_impl: Any,
                  set_layer_to_bitwidth: Callable,
-                 get_quant_node_name: Callable,
                  disable_activation_for_metric: bool = False):
         """
         Initiates all relevant objects to manage a sensitivity evaluation for MP search.
@@ -58,8 +59,6 @@ class SensitivityEvaluation:
             fw_impl: FrameworkImplementation object with a specific framework methods implementation.
             set_layer_to_bitwidth: A fw-dependent function that allows to configure a configurable MP model
                     with a specific bit-width configuration.
-            get_quant_node_name: A fw-dependent function that takes a node's name and outputs the node's name in a
-                quantized model (according to the fw conventions).
             disable_activation_for_metric: Whether to disable activation quantization when computing the MP metric.
         """
         self.graph = graph
@@ -68,7 +67,6 @@ class SensitivityEvaluation:
         self.fw_info = fw_info
         self.fw_impl = fw_impl
         self.set_layer_to_bitwidth = set_layer_to_bitwidth
-        self.get_quant_node_name = get_quant_node_name
         self.disable_activation_for_metric = disable_activation_for_metric
 
         # Get interest points for distance measurement and a list of sorted configurable nodes names
@@ -90,7 +88,9 @@ class SensitivityEvaluation:
 
         # Build a mixed-precision model which can be configured to use different bitwidth in different layers.
         # And a baseline model.
-        self.baseline_model, self.model_mp = self._build_models()
+        # Also, returns a mapping between a configurable graph's node and its matching layer(s)
+        # in the new built MP model.
+        self.baseline_model, self.model_mp, self.conf_node2layers = self._build_models()
 
         # Build images batches for inference comparison
         self.images_batches = self._get_images_batches(quant_config.num_of_images)
@@ -135,9 +135,7 @@ class SensitivityEvaluation:
         """
 
         # Configure MP model with the given configuration.
-        self._configure_bitwidths_model(self.model_mp,
-                                        self.sorted_configurable_nodes_names,
-                                        mp_model_configuration,
+        self._configure_bitwidths_model(mp_model_configuration,
                                         node_idx)
 
         # Compute the distance matrix
@@ -145,9 +143,7 @@ class SensitivityEvaluation:
 
         # Configure MP model back to the same configuration as the baseline model if baseline provided
         if baseline_mp_configuration is not None:
-            self._configure_bitwidths_model(self.model_mp,
-                                            self.sorted_configurable_nodes_names,
-                                            baseline_mp_configuration,
+            self._configure_bitwidths_model(baseline_mp_configuration,
                                             node_idx)
 
         return self._compute_mp_distance_measure(distance_matrix, self.quant_config.distance_weighting_method)
@@ -177,17 +173,17 @@ class SensitivityEvaluation:
                 for c in n.candidates_quantization_cfg:
                     c.activation_quantization_cfg.enable_activation_quantization = False
 
-        model_mp, _ = self.fw_impl.model_builder(evaluation_graph,
-                                                 mode=ModelBuilderMode.MIXEDPRECISION,
-                                                 append2output=self.interest_points,
-                                                 fw_info=self.fw_info)
+        model_mp, _, conf_node2layers = self.fw_impl.model_builder(evaluation_graph,
+                                                                   mode=ModelBuilderMode.MIXEDPRECISION,
+                                                                   append2output=self.interest_points,
+                                                                   fw_info=self.fw_info)
 
         # Build a baseline model.
         baseline_model, _ = self.fw_impl.model_builder(evaluation_graph,
                                                        mode=ModelBuilderMode.FLOAT,
                                                        append2output=self.interest_points)
 
-        return baseline_model, model_mp
+        return baseline_model, model_mp, conf_node2layers
 
     def _compute_gradient_based_weights(self) -> np.ndarray:
         """
@@ -215,8 +211,6 @@ class SensitivityEvaluation:
         return np.mean(grad_per_batch, axis=0)
 
     def _configure_bitwidths_model(self,
-                                   model_mp: Any,
-                                   sorted_configurable_nodes_names: List[str],
                                    mp_model_configuration: List[int],
                                    node_idx: List[int]):
         """
@@ -224,8 +218,6 @@ class SensitivityEvaluation:
         bit-width can be configured) using an MP model configuration mp_model_configuration.
 
         Args:
-            model_mp: Dynamic model to configure.
-            sorted_configurable_nodes_names: List of configurable nodes names sorted topology.
             mp_model_configuration: Configuration of bit-width indices to set to the model.
             node_idx: List of nodes' indices to configure (the rest layers are configured as the baseline model).
         """
@@ -235,26 +227,38 @@ class SensitivityEvaluation:
         # Thus, the last configurable layer must be included in the interest points for evaluating the metric,
         # otherwise, not all configurable nodes will be considered throughout the MP optimization search (since
         # they will not affect the metric value).
-        model_mp_layers_names = self.fw_impl.get_model_layers_names(model_mp)
         if node_idx is not None:  # configure specific layers in the mp model
             for node_idx_to_configure in node_idx:
-                node_name = self.get_quant_node_name(sorted_configurable_nodes_names[node_idx_to_configure])
-                if node_name in model_mp_layers_names:
-                    current_layer = self.fw_impl.get_model_layer_by_name(model_mp, node_name)
-                    self.set_layer_to_bitwidth(current_layer, mp_model_configuration[node_idx_to_configure])
-                else:
-                    raise Exception("The last configurable node is not included in the list of interest points for"  # pragma: no cover
-                                    "sensitivity evaluation metric for the mixed-precision search.")
-
+                self._configure_node_bitwidth(self.sorted_configurable_nodes_names,
+                                              mp_model_configuration, node_idx_to_configure)
         else:  # use the entire mp_model_configuration to configure the model
             for node_idx_to_configure, bitwidth_idx in enumerate(mp_model_configuration):
-                node_name = self.get_quant_node_name(sorted_configurable_nodes_names[node_idx_to_configure])
-                if node_name in model_mp_layers_names:
-                    current_layer = self.fw_impl.get_model_layer_by_name(model_mp, node_name)
-                    self.set_layer_to_bitwidth(current_layer, mp_model_configuration[node_idx_to_configure])
-                else:
-                    raise Exception("The last configurable node is not included in the list of interest points for"
-                                    "sensitivity evaluation metric for the mixed-precision search.")  # pragma: no cover
+                self._configure_node_bitwidth(self.sorted_configurable_nodes_names,
+                                              mp_model_configuration, node_idx_to_configure)
+
+    def _configure_node_bitwidth(self,
+                                 sorted_configurable_nodes_names: List[str],
+                                 mp_model_configuration: List[int],
+                                 node_idx_to_configure: int):
+        """
+        Configures a node with multiple quantization candidates to the bitwidth candidate in the given index.
+        Args:
+            sorted_configurable_nodes_names: A list of configurable nodes names sorted according to the graph
+                topological sort order.
+            mp_model_configuration: Configuration of bit-width indices to set to the model.
+            node_idx_to_configure: Quantization configuration candidate to configure.
+
+        Returns:
+
+        """
+        node_name = sorted_configurable_nodes_names[node_idx_to_configure]
+        layers_to_config = self.conf_node2layers.get(node_name, None)
+        if layers_to_config is None:
+            Logger.error(
+                f"Couldn't find matching layers in the MP model for node {node_name}.")  # pragma: no cover
+
+        for current_layer in layers_to_config:
+            self.set_layer_to_bitwidth(current_layer, mp_model_configuration[node_idx_to_configure])
 
     def _compute_distance_matrix(self,
                                  baseline_tensors: List[Any],
@@ -276,12 +280,16 @@ class SensitivityEvaluation:
         distance_matrix = np.ndarray((num_interest_points, num_samples))
 
         for i in range(num_interest_points):
+            point_node = self.interest_points[i]
             point_distance_fn = \
-                self.fw_impl.get_node_distance_fn(layer_class=self.interest_points[i].layer_class,
-                                                  framework_attrs=self.interest_points[i].framework_attr,
+                self.fw_impl.get_node_distance_fn(layer_class=point_node.layer_class,
+                                                  framework_attrs=point_node.framework_attr,
                                                   compute_distance_fn=self.quant_config.compute_distance_fn)
 
-            distance_matrix[i] = point_distance_fn(baseline_tensors[i], mp_tensors[i], batch=True)
+            axis = point_node.framework_attr.get(AXIS) if not isinstance(point_node, FunctionalNode) \
+                else point_node.op_call_kwargs.get(AXIS)
+
+            distance_matrix[i] = point_distance_fn(baseline_tensors[i], mp_tensors[i], batch=True, axis=axis)
 
         return distance_matrix
 
