@@ -15,8 +15,10 @@
 import copy
 from typing import List
 
+from model_compression_toolkit.target_platform_capabilities.target_platform import QuantizationMethod
+
 from model_compression_toolkit.core.common import Graph, BaseNode
-from model_compression_toolkit.core.common.constants import FLOAT_BITWIDTH
+from model_compression_toolkit.constants import FLOAT_BITWIDTH
 from model_compression_toolkit.core.common.quantization.candidate_node_quantization_config import \
     CandidateNodeQuantizationConfig
 
@@ -38,6 +40,31 @@ def filter_nodes_candidates(graph: Graph):
     return graph
 
 
+def _filter_bit_method_dups(candidates: List[CandidateNodeQuantizationConfig]) -> List[CandidateNodeQuantizationConfig]:
+    """
+    Filters out duplications in candidates configuration list, based on similarity in
+    (weights_n_bits, weights_quantization_method, activation_n_bits, activation_quantization_method).
+
+    Args:
+        candidates: A list of quantization configuration candidates.
+
+    Returns: A filtered list of quantization configuration candidates.
+
+    """
+    seen_bits_method_combinations = set()
+    final_candidates = []
+    for c in candidates:
+        comb = (c.weights_quantization_cfg.weights_n_bits,
+                c.weights_quantization_cfg.weights_quantization_method,
+                c.activation_quantization_cfg.activation_n_bits,
+                c.activation_quantization_cfg.activation_quantization_method)
+        if comb not in seen_bits_method_combinations:
+            final_candidates.append(c)
+            seen_bits_method_combinations.add(comb)
+
+    return final_candidates
+
+
 def filter_node_candidates(node: BaseNode) -> List[CandidateNodeQuantizationConfig]:
     """
     Updates a node's candidates configuration list.
@@ -51,6 +78,7 @@ def filter_node_candidates(node: BaseNode) -> List[CandidateNodeQuantizationConf
     """
 
     filtered_candidates = copy.deepcopy(node.candidates_quantization_cfg)
+    final_candidates = copy.deepcopy(node.candidates_quantization_cfg)
 
     if not node.is_weights_quantization_enabled() and not node.is_activation_quantization_enabled():
         # If both weights and activation quantization are disabled, but for some reason the node has multiple candidates
@@ -58,7 +86,9 @@ def filter_node_candidates(node: BaseNode) -> List[CandidateNodeQuantizationConf
         single_dummy_candidate = filtered_candidates[0]
         single_dummy_candidate.activation_quantization_cfg.activation_n_bits = FLOAT_BITWIDTH
         single_dummy_candidate.weights_quantization_cfg.weights_n_bits = FLOAT_BITWIDTH
-        filtered_candidates = [single_dummy_candidate]
+        single_dummy_candidate.weights_quantization_cfg.weights_quantization_method = QuantizationMethod.POWER_OF_TWO
+        single_dummy_candidate.activation_quantization_cfg.activation_quantization_method = QuantizationMethod.POWER_OF_TWO
+        final_candidates = [single_dummy_candidate]
 
     elif not node.is_activation_quantization_enabled():
         # Remove candidates that have duplicated weights candidates for node with disabled activation quantization.
@@ -70,6 +100,9 @@ def filter_node_candidates(node: BaseNode) -> List[CandidateNodeQuantizationConf
 
         for c in filtered_candidates:
             c.activation_quantization_cfg.activation_n_bits = FLOAT_BITWIDTH
+            c.activation_quantization_cfg.activation_quantization_method = QuantizationMethod.POWER_OF_TWO
+
+        final_candidates = _filter_bit_method_dups(filtered_candidates)
 
     elif not node.is_weights_quantization_enabled():
         # Remove candidates that have duplicated activation candidates for node with disabled weights quantization.
@@ -81,5 +114,8 @@ def filter_node_candidates(node: BaseNode) -> List[CandidateNodeQuantizationConf
 
         for c in filtered_candidates:
             c.weights_quantization_cfg.weights_n_bits = FLOAT_BITWIDTH
+            c.weights_quantization_cfg.weights_quantization_method = QuantizationMethod.POWER_OF_TWO
 
-    return filtered_candidates
+        final_candidates = _filter_bit_method_dups(filtered_candidates)
+
+    return final_candidates
