@@ -15,8 +15,8 @@
 
 import numpy as np
 
-from model_compression_toolkit.core.common.logger import Logger
-from model_compression_toolkit.core.common.constants import RANGE_MIN, RANGE_MAX, THRESHOLD
+from model_compression_toolkit.logger import Logger
+from model_compression_toolkit.constants import RANGE_MIN, RANGE_MAX, THRESHOLD
 from model_compression_toolkit.core.common.quantization.quantizers.quantizers_helpers import uniform_quantize_tensor, \
     quantize_tensor
 
@@ -55,6 +55,9 @@ def power_of_two_quantizer(tensor_data: np.ndarray,
         Logger.error(f"{THRESHOLD} parameter must be defined in 'quantization_params'")  # pragma: no cover
     if not threshold_is_power_of_two(threshold, per_channel):
         Logger.error(f"Expects {THRESHOLD} parameter to be a power of two, but got {threshold}")  # pragma: no cover
+    if (per_channel and (threshold <= 0).any()) or ((not per_channel) and threshold <= 0):
+        Logger.error(f"{THRESHOLD} parameter must positive")  # pragma: no cover
+
 
     return quantize_tensor(tensor_data,
                            threshold,
@@ -87,6 +90,9 @@ def symmetric_quantizer(tensor_data: np.ndarray,
     if threshold is None:
         Logger.error(f"{THRESHOLD} parameter must be defined in 'quantization_params'")  # pragma: no cover
 
+    if (per_channel and np.any(threshold <= 0)) or (not per_channel and threshold <= 0):
+        Logger.error(f"{THRESHOLD} parameter must positive")  # pragma: no cover
+
     return quantize_tensor(tensor_data,
                            threshold,
                            n_bits,
