@@ -13,23 +13,17 @@
 # limitations under the License.
 # ==============================================================================
 
-from abc import abstractmethod
-
 import tensorflow as tf
-from keras.engine.input_layer import InputLayer
-from keras.models import Model, clone_model
+from keras.models import Model
 from packaging import version
 
 from model_compression_toolkit.core.common.back2framework.base_model_builder import BaseModelBuilder
 from model_compression_toolkit.core.common.user_info import UserInformation
-from model_compression_toolkit.core.common.constants import INPUT_BASE_NAME
 
-# As from Tensorflow 2.6, keras is a separate package and some classes should be imported differently.
-if version.parse(tf.__version__) < version.parse("2.6"):
-    from tensorflow.keras.layers import Input
-    from tensorflow.python.keras.layers.core import TFOpLambda
-    from tensorflow.python.keras.engine.base_layer import TensorFlowOpLayer
-    from tensorflow.python.keras.layers import Layer
+if version.parse(tf.__version__) >= version.parse("2.13"):
+    from keras import Input
+    from keras.src.layers.core import TFOpLambda
+    from keras.src.engine.base_layer import TensorFlowOpLayer, Layer
 else:
     from keras import Input
     from keras.layers.core import TFOpLambda
@@ -38,7 +32,6 @@ else:
 from typing import Any, Dict, List, Tuple, Callable
 from tensorflow.python.util.object_identity import Reference as TFReference
 from model_compression_toolkit.core.common.graph.functional_node import FunctionalNode
-from model_compression_toolkit.core.common.logger import Logger
 from model_compression_toolkit.core import common
 from model_compression_toolkit.core.common.framework_info import FrameworkInfo
 from model_compression_toolkit.core.keras.default_framework_info import DEFAULT_KERAS_INFO
@@ -95,7 +88,8 @@ class KerasModelBuilder(BaseModelBuilder):
                  append2output=None,
                  fw_info: FrameworkInfo = DEFAULT_KERAS_INFO,
                  return_float_outputs: bool = False,
-                 wrapper: Callable = None):
+                 wrapper: Callable = None,
+                 get_activation_quantizer_holder_fn: Callable=None):
         """
 
         Args:
@@ -104,6 +98,8 @@ class KerasModelBuilder(BaseModelBuilder):
             fw_info: Information about the specific framework of the model that is built.
             return_float_outputs: Whether the model returns float tensors or not.
             wrapper: A function wrapper keras Layers.
+            get_activation_quantizer_holder_fn: Function to retrieve a quantization holder for a node.
+
         """
 
         super().__init__(graph,
@@ -112,8 +108,22 @@ class KerasModelBuilder(BaseModelBuilder):
                          return_float_outputs)
 
         # Build an OperationHandler to handle conversions from graph nodes to Keras operators.
-        self.oh = OperationHandler(self.graph)
+        self.oh = OperationHandler(self.graph,
+                                   wrapper=wrapper)
         self.wrapper = wrapper
+        self.get_activation_quantizer_holder = get_activation_quantizer_holder_fn
+
+    @property
+    def use_activation_holder_during_model_building(self) -> bool:
+        """
+
+        Returns: Whether the model builder uses KerasActivationQuantizationHolder during
+        model building (by adding it as a layer when converting the graph to the Keras model)
+        or not. If so - the model builder expects the activation quantizers to not be wrapped
+        in KerasQuantizeWrapper that was received in its init.
+
+        """
+        return self.get_activation_quantizer_holder is not None
 
     def _quantize_node_activations(self,
                                    node: BaseNode,
@@ -153,16 +163,8 @@ class KerasModelBuilder(BaseModelBuilder):
         # Hold a dictionary from an input node to its corresponding input tensor. It is needed for when
         # building the model. Initially input nodes with input tensors are added to the dictionary,
         # as they're not added later.
-        input_nodes_to_input_tensors = {inode: Input(inode.framework_attr[BATCH_INPUT_SHAPE][1:],
-                                                     name=f'{inode.name}_{INPUT_BASE_NAME}')
-                                        for
-                                        inode in self.graph.get_inputs()}
-
-        # Support adding Layer after input layers require us to store it in layer_to_node_dict
-        # dict offline (unlike other layers which stored during running).
-        for node, layer in self.oh.node_to_fw_op_dict.items():
-            if node.type == InputLayer:
-                self.oh.layer_to_node_dict[layer] = node
+        input_nodes_to_input_tensors = {inode: Input(inode.framework_attr[BATCH_INPUT_SHAPE][1:], name=inode.name)
+                                        for inode in self.graph.get_inputs()}
 
         # Build a list of the model's input tensors. Switching from a dictionary to a list
         # to keep the tensors input order, since inputs in Graph are ordered by their indices.
@@ -173,6 +175,7 @@ class KerasModelBuilder(BaseModelBuilder):
         # Build a dictionary from node to its output tensors, by applying the layers sequentially.
         for n in self.oh.node_sort:
             op_func = self.oh.get_node_op_function(n)  # Get node operation function
+
             input_tensors = self._build_input_tensors_list(n,
                                                            node_to_output_tensors_dict)  # Fetch Node inputs
             out_tensors_of_n, out_tensors_of_n_float = self._run_operation(n,  # Run node operation and fetch outputs
@@ -187,9 +190,8 @@ class KerasModelBuilder(BaseModelBuilder):
                 node_to_output_tensors_dict.update({n: [out_tensors_of_n]})
                 node_to_output_tensors_dict_float.update({n: [out_tensors_of_n_float]})
 
-        # convert node_to_output_tensors_dict keys to nodes' names since oh.node_sort contains different objects
-        # than
-        # original graph nodes.
+        # convert node_to_output_tensors_dict keys to nodes' names since oh.node_sort
+        # contains different objects than original graph nodes.
         node_name_to_outtensors = self._convert_node2name(node_to_output_tensors_dict)
         node_name_to_outtensors_float = self._convert_node2name(node_to_output_tensors_dict_float)
 
@@ -210,19 +212,6 @@ class KerasModelBuilder(BaseModelBuilder):
         # Build the model.
         model = tf.keras.Model(inputs=inputs_list, outputs=model_output_tensors)
 
-        if self.wrapper is not None:
-            def _wrap(layer):
-                _node = self.oh.layer_to_node_dict.get(layer)
-                if _node is not None:
-                    return self.wrapper(_node, layer)
-                elif is_layer_fake_quant(layer):
-                    return layer
-                raise Exception(  # pragma: no cover
-                    f'Mismatch between keras model and graph cant find node named: '
-                    f'{get_node_name_from_layer(layer)}')
-
-            model = clone_model(model, clone_function=_wrap)
-
         return model, self.graph.user_info
 
     def _convert_node2name(self, in_node_to_output_tensors_dict):
@@ -241,7 +230,6 @@ class KerasModelBuilder(BaseModelBuilder):
 
         Args:
             node: Node to build its input tensors list.
-            graph: Graph the node is in.
             node_to_output_tensors_dict: A dictionary from a node to its output tensors.
 
         Returns:
@@ -278,13 +266,8 @@ class KerasModelBuilder(BaseModelBuilder):
         """
         if len(input_tensors) == 0:  # Placeholder handling
             out_tensors_of_n_float = input_nodes_to_input_tensors[n]
-            if self.wrapper is not None:
-                # if a wrapper is defined, add an identity layer for cloning. The Identity will be warpped
-                out_tensors_of_n = op_func(out_tensors_of_n_float)
-            elif n.is_activation_quantization_enabled():
-                out_tensors_of_n = self._quantize_node_activations(n, out_tensors_of_n_float)
-            else:
-                out_tensors_of_n = out_tensors_of_n_float
+            out_tensors_of_n = self._run_operation_activation_quantization(n,
+                                                                           out_tensors_of_n_float)
         else:
             input_tensors = [tensor for tensor_list in input_tensors for tensor in tensor_list]  # flat list of lists
             # Build a functional node using its args
@@ -299,11 +282,9 @@ class KerasModelBuilder(BaseModelBuilder):
                 if len(input_tensors) == 1:
                     input_tensors = input_tensors[0]
                 out_tensors_of_n_float = op_func(input_tensors)
-            out_tensors_of_n = out_tensors_of_n_float
 
-            # Add a fake quant node if the node has an activation threshold and a wrapper isn't defined
-            if n.is_activation_quantization_enabled() and self.wrapper is None:
-                out_tensors_of_n = self._quantize_node_activations(n, out_tensors_of_n_float)
+            out_tensors_of_n = self._run_operation_activation_quantization(n,
+                                                                           out_tensors_of_n_float)
 
         # Save a mapping from the layer that created the tensor to the node (as this layer is not the
         # same instance as op_func. We do this to solve an issue that names are different between these
@@ -318,3 +299,32 @@ class KerasModelBuilder(BaseModelBuilder):
             self.oh.layer_to_node_dict[layer_from_tensor] = n
 
         return out_tensors_of_n, out_tensors_of_n_float
+
+    def _run_operation_activation_quantization(self,
+                                               node: BaseNode,
+                                               node_outputs: List[TFReference]):
+        """
+        Quantize node's activations
+
+        Args:
+            node: Node to quantize its activations
+            node_outputs: Output tensors of the float node.
+
+        Returns:
+            Quantized node's outputs.
+        """
+        if self.wrapper is not None:
+
+            # In case the activation quantizer is attached out of the wrapper we use get_activation_quantizer_holder
+            # for the activation quantization holder (if the node's activations are quantized)
+            if node.is_activation_quantization_enabled() and self.use_activation_holder_during_model_building:
+                activation_quantizer_holder = self.get_activation_quantizer_holder(node)
+                quantized_node_outputs = activation_quantizer_holder(node_outputs)
+                return quantized_node_outputs
+
+        elif node.is_activation_quantization_enabled():  # Used only when old exporter is used
+            quantized_node_outputs = self._quantize_node_activations(node,
+                                                                     node_outputs)
+            return quantized_node_outputs
+
+        return node_outputs
