@@ -19,20 +19,20 @@ from packaging import version
 # As from Tensorflow 2.6, keras is a separate package and some classes should be imported differently.
 from tqdm import tqdm
 
-if version.parse(tf.__version__) < version.parse("2.6"):
-    from tensorflow.python.keras.layers import Layer  # pragma: no cover
+if version.parse(tf.__version__) >= version.parse("2.13"):
+    from keras.src.engine.base_layer import Layer
 else:
-    from keras.engine.base_layer import Layer
+    from tensorflow.python.keras.engine.base_layer import Layer
 
 from typing import Any, Dict, List, Tuple
 from tensorflow.python.util.object_identity import Reference as TFReference
-from model_compression_toolkit.core.common.constants import EPS, MIN_JACOBIANS_ITER, JACOBIANS_COMP_TOLERANCE
+from model_compression_toolkit.constants import EPS, MIN_JACOBIANS_ITER, JACOBIANS_COMP_TOLERANCE
 from model_compression_toolkit.core.common.graph.functional_node import FunctionalNode
 from model_compression_toolkit.core import common
 from model_compression_toolkit.core.common import BaseNode, Graph
 from model_compression_toolkit.core.common.graph.edge import EDGE_SINK_INDEX
 from model_compression_toolkit.core.keras.back2framework.instance_builder import OperationHandler
-from model_compression_toolkit.core.common.logger import Logger
+from model_compression_toolkit.logger import Logger
 
 
 def build_input_tensors_list(node: BaseNode,
@@ -127,6 +127,10 @@ def keras_iterative_approx_jacobian_trace(graph_float: common.Graph,
     point's output has on the model's output.
     """
 
+    if len(interest_points) == 1:
+        # Only one compare point, nothing else to "weight"
+        return [1.0]
+
     if not all([images.shape[0] == 1 for node, images in model_input_tensors.items()]):
         Logger.critical("Iterative jacobian trace computation is only supported on a single image sample")  # pragma: no cover
 
