@@ -22,14 +22,14 @@ import numpy as np
 
 from model_compression_toolkit.core import common
 from model_compression_toolkit.core.common import BaseNode, Graph
-from model_compression_toolkit.core.common.constants import EPS, MIN_JACOBIANS_ITER, JACOBIANS_COMP_TOLERANCE
+from model_compression_toolkit.constants import EPS, MIN_JACOBIANS_ITER, JACOBIANS_COMP_TOLERANCE
 from model_compression_toolkit.core.common.graph.edge import EDGE_SINK_INDEX
 from model_compression_toolkit.core.common.graph.functional_node import FunctionalNode
 from model_compression_toolkit.core.pytorch.back2framework.instance_builder import node_builder
 from model_compression_toolkit.core.pytorch.constants import BUFFER
 from model_compression_toolkit.core.pytorch.reader.node_holders import DummyPlaceHolder, BufferHolder
 from model_compression_toolkit.core.pytorch.utils import torch_tensor_to_numpy, get_working_device
-from model_compression_toolkit.core.common.logger import Logger
+from model_compression_toolkit.logger import Logger
 
 
 def build_input_tensors_list(node: BaseNode,
@@ -239,6 +239,10 @@ def pytorch_iterative_approx_jacobian_trace(graph_float: common.Graph,
     point's output has on the model's output.
     """
 
+    if len(interest_points) == 1:
+        # Only one compare point, nothing else to "weight"
+        return [1.0]
+
     # Set inputs to require_grad
     for n, input_tensor in model_input_tensors.items():
         input_tensor.requires_grad_()
