@@ -14,16 +14,18 @@
 # ==============================================================================
 import operator
 from copy import deepcopy
+from functools import partial
 from typing import List, Any, Tuple, Callable, Type, Dict
 
 import numpy as np
 import torch
+from mct_quantizers import PytorchQuantizationWrapper, PytorchActivationQuantizationHolder
 from torch import sigmoid, softmax, add, cat, argmax
 from torch.nn import Conv2d, ConvTranspose2d, Linear
 from torch.nn import Module, Sigmoid, Softmax
 
 import model_compression_toolkit.core.pytorch.constants as pytorch_constants
-from model_compression_toolkit import QuantizationConfig, FrameworkInfo, CoreConfig, MixedPrecisionQuantizationConfigV2
+from model_compression_toolkit.core import QuantizationConfig, FrameworkInfo, CoreConfig, MixedPrecisionQuantizationConfigV2
 from model_compression_toolkit.core import common
 from model_compression_toolkit.core.common import Graph, BaseNode
 from model_compression_toolkit.core.common.collectors.statistics_collector import BaseStatsCollector
@@ -31,6 +33,7 @@ from model_compression_toolkit.core.common.collectors.statistics_collector_gener
     create_stats_collector_for_node
 from model_compression_toolkit.core.common.framework_implementation import FrameworkImplementation
 from model_compression_toolkit.core.common.mixed_precision.sensitivity_evaluation import SensitivityEvaluation
+from model_compression_toolkit.core.common.mixed_precision.set_layer_to_bitwidth import set_layer_to_bitwidth
 from model_compression_toolkit.core.common.model_builder_mode import ModelBuilderMode
 from model_compression_toolkit.core.common.node_prior_info import NodePriorInfo
 from model_compression_toolkit.core.common.similarity_analyzer import compute_mse, compute_kl_divergence, compute_cs
@@ -40,7 +43,7 @@ from model_compression_toolkit.core.pytorch.back2framework.model_gradients impor
     pytorch_iterative_approx_jacobian_trace
 from model_compression_toolkit.core.pytorch.default_framework_info import DEFAULT_PYTORCH_INFO
 from model_compression_toolkit.core.pytorch.graph_substitutions.substitutions.batchnorm_folding import \
-    pytorch_batchnorm_folding
+    pytorch_batchnorm_folding, pytorch_batchnorm_forward_folding
 from model_compression_toolkit.core.pytorch.graph_substitutions.substitutions.batchnorm_reconstruction import \
     pytorch_batchnorm_reconstruction
 from model_compression_toolkit.core.pytorch.graph_substitutions.substitutions.batchnorm_refusing import \
@@ -70,19 +73,20 @@ from model_compression_toolkit.core.pytorch.graph_substitutions.substitutions.vi
     VirtualActivationWeightsComposition
 from model_compression_toolkit.core.pytorch.graph_substitutions.substitutions.weights_activation_split import \
     WeightsActivationSplit
-from model_compression_toolkit.core.pytorch.mixed_precision.set_layer_to_bitwidth import set_layer_to_bitwidth
+from model_compression_toolkit.core.pytorch.mixed_precision.configurable_activation_quantizer import \
+    ConfigurableActivationQuantizer
+from model_compression_toolkit.core.pytorch.mixed_precision.configurable_weights_quantizer import \
+    ConfigurableWeightsQuantizer
 from model_compression_toolkit.core.pytorch.pytorch_node_prior_info import create_node_prior_info
 from model_compression_toolkit.core.pytorch.reader.reader import model_reader
 from model_compression_toolkit.core.pytorch.statistics_correction.apply_second_moment_correction import \
     pytorch_apply_second_moment_correction
 from model_compression_toolkit.core.pytorch.utils import to_torch_tensor, torch_tensor_to_numpy, set_model
-from model_compression_toolkit.gptq.common.gptq_training import GPTQTrainer
-from model_compression_toolkit.gptq.pytorch.gptq_training import PytorchGPTQTrainer
 
 
 class PytorchImplementation(FrameworkImplementation):
     """
-    An class with implemented methods to support optimizing Pytorch models.
+    A class with implemented methods to support optimizing Pytorch models.
     """
 
     def __init__(self):
@@ -136,7 +140,7 @@ class PytorchImplementation(FrameworkImplementation):
                       mode: ModelBuilderMode,
                       append2output: List[Any] = None,
                       fw_info: FrameworkInfo = DEFAULT_PYTORCH_INFO,
-                      return_float_outputs: bool = False) -> Tuple[Module, UserInformation]:
+                      return_float_outputs: bool = False) -> Tuple:
         """
         Build a Pytorch module from a graph.
         The mode determines how the module should be build. append2output is a list of Nodes
@@ -150,7 +154,7 @@ class PytorchImplementation(FrameworkImplementation):
             return_float_outputs (bool): whether to return outputs before or after quantization nodes (default)
 
         Returns:
-            A tuple of the Pytorch module that was built and an UserInformation object.
+            A tuple with the model and additional relevant supporting objects.
         """
         pytorch_model_builder = get_pytorch_model_builder(mode)
         return pytorch_model_builder(graph=graph,
@@ -245,7 +249,8 @@ class PytorchImplementation(FrameworkImplementation):
 
         Returns: A list of the framework substitutions used before we build a quantized module.
         """
-        substitutions_list = [pytorch_batchnorm_folding()]
+        substitutions_list = [pytorch_batchnorm_folding(),
+                              pytorch_batchnorm_forward_folding()]
         if quant_config.relu_bound_to_power_of_2:
             substitutions_list.append(ReLUBoundToPowerOfTwo())
         return substitutions_list
@@ -325,12 +330,6 @@ class PytorchImplementation(FrameworkImplementation):
             substitutions_list.append(pytorch_batchnorm_refusing())
         return substitutions_list
 
-    def get_gptq_trainer_obj(self) -> Type[GPTQTrainer]:
-        """
-        Returns: GPTQTrainer object
-        """
-        return PytorchGPTQTrainer
-
     def get_sensitivity_evaluator(self,
                                   graph: Graph,
                                   quant_config: MixedPrecisionQuantizationConfigV2,
@@ -357,8 +356,11 @@ class PytorchImplementation(FrameworkImplementation):
                                      representative_data_gen=representative_data_gen,
                                      fw_info=fw_info,
                                      fw_impl=self,
-                                     set_layer_to_bitwidth=set_layer_to_bitwidth,
-                                     get_quant_node_name=lambda node_name: f'{node_name}',
+                                     set_layer_to_bitwidth=partial(set_layer_to_bitwidth,
+                                                                   weights_quantizer_type=ConfigurableWeightsQuantizer,
+                                                                   activation_quantizer_type=ConfigurableActivationQuantizer,
+                                                                   weights_quant_layer_type=PytorchQuantizationWrapper,
+                                                                   activation_quant_layer_type=PytorchActivationQuantizationHolder),
                                      disable_activation_for_metric=disable_activation_for_metric)
 
     def get_node_prior_info(self,
@@ -387,7 +389,8 @@ class PytorchImplementation(FrameworkImplementation):
         Returns: True if the node should be considered an interest point, False otherwise.
         """
 
-        if node.type in [Conv2d, Linear, ConvTranspose2d, Sigmoid, sigmoid, Softmax, softmax, operator.add, add, cat]:
+        if node.type in [Conv2d, Linear, ConvTranspose2d, Sigmoid, sigmoid, Softmax, softmax, operator.add, add, cat,
+                         operator.concat]:
             return True
         return False
 
@@ -418,36 +421,6 @@ class PytorchImplementation(FrameworkImplementation):
             return compute_cs
         return compute_mse
 
-    def get_model_layers_names(self,
-                               model: Module) -> List[str]:
-        """
-        Returns a list of the given model's layers names.
-
-        Args:
-            model: A Pytorch model.
-
-        Returns: List of layers' names.
-
-        """
-
-        return [layer[0] for layer in list(model.named_children())]
-
-    def get_model_layer_by_name(self,
-                                model: Module,
-                                layer_name: str) -> Module:
-        """
-        Returns a Pytorch model's layer by its name.
-
-        Args:
-            model: A Pytorch model to retrieve a layer from.
-            layer_name: The requested layer's name.
-
-        Returns: A Pytorch layer object.
-
-        """
-
-        return model.get_submodule(target=layer_name)
-
     def model_grad(self,
                    graph_float: common.Graph,
                    model_input_tensors: Dict[BaseNode, torch.Tensor],
@@ -494,7 +467,7 @@ class PytorchImplementation(FrameworkImplementation):
 
         """
 
-        return node.layer_class not in [argmax, softmax]
+        return node.layer_class not in [argmax, softmax, Softmax]
 
     def get_node_mac_operations(self,
                                 node: BaseNode,
@@ -509,7 +482,6 @@ class PytorchImplementation(FrameworkImplementation):
         Returns: The MAC count of the operation
         """
 
-        input_shape = node.input_shape[0]
         output_shape = node.output_shape[0]
         kernel_shape = node.get_weights_by_keys(fw_info.get_kernel_op_attributes(node.type)[0]).shape
         output_channel_axis, input_channel_axis = fw_info.kernel_channels_mapping.get(node.type)
@@ -517,7 +489,7 @@ class PytorchImplementation(FrameworkImplementation):
         if node.type is Conv2d or node.type is ConvTranspose2d:
             # (C_out * W_out * H_out) * C_in * (W_kernel * H_kernel)
             return np.prod([x for x in output_shape if x is not None]) * \
-                   input_shape[input_channel_axis] * \
+                   kernel_shape[input_channel_axis] * \
                    (kernel_shape[0] * kernel_shape[1])
         elif node.type is Linear:
             # IN * OUT
