@@ -13,7 +13,10 @@
 # limitations under the License.
 # ==============================================================================
 
-from model_compression_toolkit.exporter.model_exporter.keras.keras_export_facade import keras_export_model, KerasExportMode
-from model_compression_toolkit.exporter.model_exporter.pytorch.pytorch_export_facade import PyTorchExportMode, pytorch_export_model
-from model_compression_toolkit.exporter.model_exporter.tflite.tflite_export_facade import tflite_export_model, TFLiteExportMode
+from model_compression_toolkit.exporter.model_exporter.keras.export_serialization_format import \
+    KerasExportSerializationFormat
+from model_compression_toolkit.exporter.model_exporter.pytorch.export_serialization_format import \
+    PytorchExportSerializationFormat
+from model_compression_toolkit.exporter.model_exporter.keras.keras_export_facade import keras_export_model
+from model_compression_toolkit.exporter.model_exporter.pytorch.pytorch_export_facade import pytorch_export_model
 
