@@ -16,23 +16,24 @@ from typing import Callable, List, Tuple, Union
 
 import tensorflow as tf
 from keras import Model
+from packaging import version
 from tensorflow.keras.layers import Layer
 from tqdm import tqdm
 
 # As from Tensorflow 2.6, keras is a separate package and some classes should be imported differently.
 from model_compression_toolkit.core.common.user_info import UserInformation
 from model_compression_toolkit.core.keras.back2framework.keras_model_builder import KerasModelBuilder
-from packaging import version
-
 from model_compression_toolkit.gptq.common.gptq_graph import get_kernel_attribute_name_for_gptq
 from model_compression_toolkit.gptq.keras.quantizer.quantization_builder import quantization_builder
-from model_compression_toolkit.quantizers_infrastructure import KerasQuantizationWrapper
+from model_compression_toolkit.logger import Logger
+from mct_quantizers import KerasActivationQuantizationHolder
 
-if version.parse(tf.__version__) < version.parse("2.6"):
-    from tensorflow.python.keras.engine.base_layer import TensorFlowOpLayer
+if version.parse(tf.__version__) >= version.parse("2.13"):
+    from keras.src.engine.base_layer import TensorFlowOpLayer
 else:
     from keras.engine.base_layer import TensorFlowOpLayer
 
+from model_compression_toolkit.trainable_infrastructure import KerasTrainableQuantizationWrapper
 from model_compression_toolkit.core import common
 from model_compression_toolkit.gptq.common.gptq_training import GPTQTrainer
 from model_compression_toolkit.gptq.common.gptq_config import GradientPTQConfigV2
@@ -44,7 +45,6 @@ from model_compression_toolkit.core.common.framework_implementation import Frame
 import numpy as np
 import copy
 from model_compression_toolkit.core.keras.constants import BIAS, USE_BIAS
-from model_compression_toolkit import quantizers_infrastructure as qi
 
 
 class KerasGPTQTrainer(GPTQTrainer):
@@ -105,7 +105,7 @@ class KerasGPTQTrainer(GPTQTrainer):
             [len(optimizer_params_tuple[1]) for optimizer_params_tuple in self.optimizer_with_param]) > 0
 
         if self.float_user_info.input_scale != self.gptq_user_info.input_scale:
-            common.Logger.error("Input scale mismatch between float and GPTQ networks")  # pragma: no cover
+            Logger.error("Input scale mismatch between float and GPTQ networks")  # pragma: no cover
         else:
             self.input_scale = self.gptq_user_info.input_scale
 
@@ -113,8 +113,8 @@ class KerasGPTQTrainer(GPTQTrainer):
 
         self.reg_func = get_regularization(self.gptq_config, representative_data_gen)
 
-    def _is_gptq_applicable(self,
-                            node: common.BaseNode) -> bool:
+    def _is_gptq_weights_trainable(self,
+                                   node: common.BaseNode) -> bool:
         """
         A function for deciding if a layer should be fine-tuned during GPTQ.
 
@@ -126,11 +126,13 @@ class KerasGPTQTrainer(GPTQTrainer):
         """
 
         if node.is_weights_quantization_enabled() and not self.fw_info.is_kernel_op(node.type):
-            common.Logger.error(f"GPTQ Error: Quantizing node {node.name} of type {node.type} "
+            Logger.error(f"GPTQ Error: Quantizing node {node.name} of type {node.type} "
                                 f"without a kernel isn't supported")
         return node.is_weights_quantization_enabled()
 
-    def gptq_wrapper(self, n: common.BaseNode, layer: Layer) -> Union[qi.KerasQuantizationWrapper, Layer]:
+    def gptq_wrapper(self,
+                     n: common.BaseNode,
+                     layer: Layer) -> Union[KerasTrainableQuantizationWrapper, Layer]:
         """
         A function which takes a computational graph node and a keras layer and perform the quantization wrapping.
 
@@ -141,13 +143,37 @@ class KerasGPTQTrainer(GPTQTrainer):
         Returns: Wrapped layer if the layer should be wrap, otherwise returns the layer as is.
 
         """
-        if self._is_gptq_applicable(n):
-            weights_quantizers, activation_quantizers = quantization_builder(n, self.gptq_config)
-            return qi.KerasQuantizationWrapper(layer,
-                                               weights_quantizers=weights_quantizers,
-                                               activation_quantizers=activation_quantizers)
-        else:
-            return layer
+        if self._is_gptq_weights_trainable(n):
+            weights_quantizers, _ = quantization_builder(n,
+                                                         self.gptq_config) # TODO: split quantizers building into two functions: for weights and activations
+            if len(weights_quantizers) > 0:
+                return KerasTrainableQuantizationWrapper(layer,
+                                                   weights_quantizers=weights_quantizers)
+        return layer
+
+    def get_activation_quantizer_holder(self, n: common.BaseNode) -> Callable:
+        """
+        Retrieve a KerasActivationQuantizationHolder layer to use for activation quantization for a node.
+        If the layer is not supposed to be wrapped with activation quantizers - return None.
+
+        Args:
+            n: Node to get KerasActivationQuantizationHolder to attach in its output.
+
+        Returns:
+            A KerasActivationQuantizationHolder layer for the node activation quantization.
+        """
+        _, activation_quantizers = quantization_builder(n, self.gptq_config) # TODO: split quantizers building into two functions: for weights and activations
+
+        # Holder by definition uses a single quantizer for the activation quantization
+        # thus we make sure this is the only possible case (unless it's a node with no activation
+        # quantization, which in this case has an empty list).
+        if len(activation_quantizers) == 1:
+            return KerasActivationQuantizationHolder(activation_quantizers[0])
+
+        Logger.error(
+            f'KerasActivationQuantizationHolder supports a single quantizer but {len(activation_quantizers)} quantizers '
+            f'were found for node {n}')
+
 
     def build_gptq_model(self) -> Tuple[Model, UserInformation]:
         """
@@ -161,7 +187,8 @@ class KerasGPTQTrainer(GPTQTrainer):
                                                        append2output=self.compare_points,
                                                        fw_info=self.fw_info,
                                                        return_float_outputs=True,
-                                                       wrapper=self.gptq_wrapper).build_model()
+                                                       wrapper=self.gptq_wrapper,
+                                                       get_activation_quantizer_holder_fn=self.get_activation_quantizer_holder).build_model()
 
         return gptq_model, gptq_user_info
 
@@ -280,7 +307,7 @@ class KerasGPTQTrainer(GPTQTrainer):
                     self.gptq_config.log_function(loss_value_step, grads[0], in_optimizer_with_param[0][-1],
                                                   self.compare_points)
                 self.loss_list.append(loss_value_step.numpy())
-                common.Logger.debug(f'last loss value: {self.loss_list[-1]}')
+                Logger.debug(f'last loss value: {self.loss_list[-1]}')
 
     def update_graph(self):
         """
@@ -292,12 +319,12 @@ class KerasGPTQTrainer(GPTQTrainer):
         graph = copy.copy(self.graph_quant)
 
         for layer in self.fxp_model.layers:
-            if isinstance(layer, KerasQuantizationWrapper):
+            if isinstance(layer, KerasTrainableQuantizationWrapper):
                 node = graph.find_node_by_name(layer.layer.name)
                 if len(node) == 0 and isinstance(layer.layer, TensorFlowOpLayer):
                     node = graph.find_node_by_name('_'.join(layer.layer.name.split('_')[3:]))
                 if len(node) != 1:
-                    common.Logger.error(f"Can't update GPTQ graph due to missing layer named: {layer.layer.name}")
+                    Logger.error(f"Can't update GPTQ graph due to missing layer named: {layer.layer.name}")
                 node = node[0]
                 kernel_attribute = get_kernel_attribute_name_for_gptq(layer_type=node.type,
                                                                       fw_info=self.fw_info)
