@@ -13,4 +13,5 @@
 # limitations under the License.
 # ==============================================================================
 
-from model_compression_toolkit.qat.keras.quantizer.configs.weight_quantizer_config import WeightQuantizeConfig
+import model_compression_toolkit.qat.keras.quantizer.ste_rounding.symmetric_ste
+import model_compression_toolkit.qat.keras.quantizer.ste_rounding.uniform_ste
